<?php
/**
 * Plugin Name: Games For Wordpress
 * Description: Welcome to Games for WordPress – Elevate engagement, boost your revenue with 300+ HTML5 games
 * Version: 1.0
 * Author: Sunendra Pradhan
 */

// Add settings page to WordPress admin menu


// Register and initialize settings fields
function game_display_settings_init() {
    register_setting('game_display_settings_group', 'game_display_api_url');
}
add_action('admin_init', 'game_display_settings_init');

// Add a top-level menu item for the plugin
function game_display_add_menu() {
    add_menu_page(
        'Games For Wordpress Settings', // Page title
        'Games For Wordpress',          // Menu title
        'manage_options',        // Capability required to access
        'game-display-settings',  // Menu slug
        'game_display_settings_page', // Callback function to display the page
        'dashicons-games' // Icon (change this to the desired icon)
    );
}
add_action('admin_menu', 'game_display_add_menu');

// Callback function to display the settings page
function game_display_settings_page() {

    ?>
    <div class="wrap">
        <h1>Game For Wordpress <small>- alpha release (v 0.1)</small></h1>
        <p>"Welcome to Games for WordPress – Elevate engagement, boost your revenue"
        <br>
        "With our simple yet powerful plugin with fun 300+ cross platform games!, you can effortlessly display engaging content on your website, captivating your users while unlocking a new revenue stream through our innovative ad revenue-sharing model. With us, publishers earn a generous 50% share of the revenue generated from their website. Get ready to showcase, engage, and profit like never before!""</p>
        <form method="post" action="options.php">
            <?php
            settings_fields('game_display_settings_group');
            do_settings_sections('game-display-settings');
            submit_button();
            ?>
        </form>


        <!-- Display API Instructions -->
        <h2>Vendor ID</h2>
        <p>
            Vendor ID is your unique identification number, that is associated with your website.<br>
            Having your own vendor ID is essential if you want to monetize your traffic using the games.<br>
            To complete the setup and start tracking revenue from your websites traffic: <a href="https://gamesforwordpress.com/join/" target="_blank">Sign Up</a>
        </p>

        <!-- Display Shortcode Section -->
        <h2>Display Games Shortcode</h2>
        <p>To display games on your page, simply copy and paste the following shortcode:</p>
        <code>[display_games]</code>
    </div>
    <?php
}

// Initialize sections and fields
function game_display_settings_sections() {
    // Section 2: Display Settings
    add_settings_section('game_display_count_settings_section', 'Played Count', '', 'game-display-settings');

    add_settings_field(
        'game_display_played_count_field',
        'Played Count',
        'game_display_played_count_field_callback',
        'game-display-settings',
        'game_display_count_settings_section'
    );
    // Section 2: Display Settings
    add_settings_section('game_display_time_settings_section', 'Played Time', '', 'game-display-settings');

    // add_settings_field(
    //     'Played Time'
    // );
    // Section 2: Display Settings
    add_settings_section('game_display_revenue_settings_section', 'Estimated Revenue', '', 'game-display-settings');

    // add_settings_field(
    //     'Estimated Revenue'
    // );
    // Section 1: API Settings
    add_settings_section('game_display_api_settings_section', 'API Settings', '', 'game-display-settings');

    add_settings_field(
        'game_display_api_url_field',
        'Vendor ID',
        'game_display_api_url_field_callback',
        'game-display-settings',
        'game_display_api_settings_section'
    );

    
}
add_action('admin_init', 'game_display_settings_sections');

// Callback function to render the settings field
function game_display_api_url_field_callback() {
    $value = get_option('game_display_api_url');
    if (!empty($value)) {
        // If the API URL is not empty, display its current value
        $value = esc_attr($value);
        ?>
            <input type="text" name="game_display_api_url" value="<?php echo esc_attr($value); ?>" />
        <?php
    } else {
        // If the API URL is empty, display default message
        ?>
            <input type="text" name="game_display_api_url"  placeholder="Enter Your Vendor ID"/>
        <?php
    }
    ?>
    
    <p class="description"><small>The plugin uses platform default value on fresh install to display games. <br>Enter your Vendor ID provided by our platform to start earning revenue form your traffic. <a href="https://gamesforwordpress.com/join/" target="_blank">Sign Up</a></small></p>
    <?php
}
// Callback function to render the settings field for Played Count
function game_display_played_count_field_callback() {
    // Fetch data from the API for Played Count
    $api_url = 'https://ramailogames.com/api/vendor/' . get_option('game_display_api_url') . '/count';
    
    if ($api_url) {
        $response = wp_remote_get($api_url);

        if (!is_wp_error($response) && $response['response']['code'] === 200) {
            $played_count_data = json_decode(wp_remote_retrieve_body($response), true);

            echo $played_count_data;

        }
    }
}
    


// Function to display games using a shortcode
function display_games_from_api() {
    wp_enqueue_style('game-display-styles', plugin_dir_url(__FILE__) . 'game-display-styles.css');
    

    // Check if game_display_api_url is empty
    $api_url = get_option('game_display_api_url');
    
    if (empty($api_url)) {
        // If empty, set a default value
        $api_url = 'https://ramailogames.com/api/vendor/' . '1666161571' . '/game-list';
    } else {
        // If not empty, construct the URL
        $api_url = 'https://ramailogames.com/api/vendor/' . $api_url . '/game-list';
    }

    if ($api_url) {
        $response = wp_remote_get($api_url);

        if (!is_wp_error($response) && $response['response']['code'] === 200) {
            $games_data = json_decode(wp_remote_retrieve_body($response), true);
            // Process $games_data (JSON response) as needed
            // Generate HTML output for games
            $html_output = '<div class="row game-list">';
                foreach ($games_data as $game) {
                    $html_output .= '<div class="col-md-2 game">';
                    // Display game details (title, image, etc.)
                    $html_output .= '<a href="' . esc_url($game['play_route']) . '">';
                    $html_output .= '<img class="game-logo" src="' . esc_url($game['logo']) . '" alt="' . esc_attr($game['title']) . '">';
                    $html_output .= '<h3>' . esc_html($game['name']) . '</h3>';
                    $html_output .= '</a>';
                    // Add more game details as needed
                    $html_output .= '</div>';
                }
            $html_output .= '</div>';
            return $html_output;
        } else {
            return 'Failed to fetch games.';
        }
    } else {
        return 'API URL not set. Please configure it in the settings.';
    }
}
add_shortcode('display_games', 'display_games_from_api');
